#
# spec file for package orthanc-wsi
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2019-2025 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orthanc-wsi
Summary:        Whole Slide Imaging for Orthanc
License:        AGPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
Version:        3.1
Release:        1.1
URL:            https://orthanc-server.com
Source0:        https://orthanc.uclouvain.be/downloads/sources/%{name}/OrthancWSI-%{version}.tar.gz
#%%Source1:        openlayers-3.19.0-dist.zip
Source1:        https://orthanc.uclouvain.be/downloads/third-party-downloads/WSI/openlayers-10.4.0-package.tar.gz
Source11:       orthanc-wsi-readme.SUSE

BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  dcmtk
BuildRequires:  dcmtk-devel
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_iostreams-devel >= 1.66
BuildRequires:  libboost_locale-devel >= 1.66
BuildRequires:  libboost_program_options-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  libicu-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libuuid-devel
# Check was missing:
BuildRequires:  libxml2-devel
BuildRequires:  tcpd-devel
# Check was missing - end
BuildRequires:  openjpeg2-devel
BuildRequires:  openssl-devel
BuildRequires:  orthanc-devel
BuildRequires:  orthanc-source
BuildRequires:  unzip

Requires:       orthanc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Orthanc project provides three official tools to support DICOM for whole-slide microscopic imaging (WSI):
- A so-called “DICOM-izer” command-line tool that converts whole-slide images to DICOM series, following Supplement 145.
- A plugin that extends Orthanc with a Web viewer of whole-slide images for digital pathology.
- Another command-line tool that converts a DICOM series stored inside Orthanc, to a standard hierarchical TIFF image.

%prep
%autosetup -n OrthancWSI-%{version}

#OrthanPlugin may ask for additional files to be loaded
#Putting them into this folder prevents download of sources from the web

mkdir ViewerPlugin/ThirdPartyDownloads
cp %{S:1} ViewerPlugin/ThirdPartyDownloads/.

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
# build the applications
cd Applications

%cmake .. \
       -DALLOW_DOWNLOADS=OFF \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/OrthancFramework/Sources \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

#and the plugins
cd ../../ViewerPlugin

%cmake .. \
       -DALLOW_DOWNLOADS=OFF \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/OrthancFramework/Sources \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

%install
cd Applications
%cmake_install
cd ../ViewerPlugin
%cmake_install

# architecture dependet files should not be in /usr/share...
# create a directory
mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins
mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc

mv %{buildroot}%{_prefix}/share/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#Link from lib64 to orthanc plugin-directory, where it is expected
ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancWSI.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancWSI.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/*.so

cp %{S:11} %{buildroot}%{_docdir}/orthanc/.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/orthanc
%{_docdir}/orthanc/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_prefix}/share/orthanc
%dir %{_prefix}/share/orthanc/plugins
%{_prefix}/share/orthanc/plugins/*.so*
%{_bindir}/OrthancWSIDicomizer
%{_bindir}/OrthancWSIDicomToTiff

%changelog
* Wed Mar 19 2025 Axel Braun <axel.braun@gmx.de>
- version 3.1
  * Upgraded to OpenLayers 10.4.0 (was previously 3.19.0)
  * The viewer now displays the scale if imaged volume size is available in DICOM
  * Fix handling of "Image Type" in the viewer for compatibility with other vendors
  * OrthancWSIDicomizer does not fill anymore the imaged volume width/height
    tags if no information is available
  * OrthancWSIDicomizer detects imaged volume size for Aperio files without OpenSlide
* Sat Dec 21 2024 Axel Braun <axel.braun@gmx.de>
- version 3.0
  * Minimum SDK version: 1.7.0
  * On-the-fly creation of pyramids from frames of DICOM instances
* Sat Oct 19 2024 Axel Braun <axel.braun@gmx.de>
- Version 2.1
  * Support of sparse encoding of tiles in OpenSlide (notably for MIRAX format)
  * OrthancWSIDicomizer supports plain TIFF, besides hierarchical TIFF
  * New option: "--force-openslide" to force the use of OpenSlide on TIFF-like files
  * New option: "--padding" to control deep zoom of plain PNG/JPEG/TIFF images over IIIF
  * Added support for DICOM tag "Recommended Absent Pixel CIELab" (0048,0015)
  * Force version of Mirador to 3.3.0
  * In the IIIF manifest, reverse the order of the "sizes" field, which
    seems to fix compatibility with Mirador v4.0.0-alpha
* Sat Jul 15 2023 Axel Braun <axel.braun@gmx.de>
- version 2.0
  * Support of IIIF
  * Automated extraction of the imaged volume if using OpenSlide
  * URI "/wsi/tiles/{id}/{z}/{x}/{y}" supports the "Accept" HTTP header
    to force JPEG, JPEG2k, or PNG in the decoded tiles
  * openjpeg.diff removed
* Thu Jun 23 2022 Axel Braun <axel.braun@gmx.de>
- openjpeg.diff added for new jpeg 2.5
* Mon Dec 13 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.1
  * OrthancWSIDicomizer: Support importing of images from Cytomine
  * orthanc193.diff removed (included in source)
* Mon May 17 2021 Axel Braun <axel.braun@gmx.de>
- orthanc193.diff added (boo#1186112)
* Thu Jan 14 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.0
  * orthanc-framework package removed
  * Viewer can display DICOM pyramids whose tile sizes vary across levels
  * Allow images without "Per frame functional groups sequence" tag (0x5200,0x9230)
  * Better handling of PhotometricInterpretation in viewer
  * Fix colorspace of TIFF containing JPEG with RGB photometric interpretation (not YCbCr)
  * Don't display the thumbnail/overview instances in the Web viewer
  * Fix issue #145 (support of Concatenation UID)
  * Support of dynamic linking against the system-wide Orthanc framework library
  * Upgraded dependencies for static builds (notably on Windows):
  - libtiff, from 4.0.6 to 4.2.0
  - openjpeg, from 2.1 to 2.4.0
* Thu Oct 22 2020 Axel Braun <axel.braun@gmx.de>
- switch to orthanc-framework (static orthanc version)
* Wed May 27 2020 Axel Braun <axel.braun@gmx.de>
- version 0.7
  * Improved consistency when transcoding/re-encoding is applied
  * Support of grayscale images
  * Fix issue #139 (OrthancWSIDicomizer PixelSpacing)
  * Fix issue #144 (OrthancWSIDicomizer PhotometricInterpretation)
  * Fix issue #163 (Failure to recognize MIRAX / 3DHISTECH images)
  * Upgrade to Orthanc framework 1.7.0
* Sun Apr 19 2020 Axel Braun <axel.braun@gmx.de>
- orthanc 1.6.0 breaks build of this plugin.
  inclusion of Orthanc 1.5.2 source and adaption of build options
  wsi.json removed (plugin definition moved to Configuration.json)
* Tue Dec 10 2019 Axel Braun <axel.braun@gmx.de>
- version 0.6
  Initial build on OBS
